@@ -4,9 +4,9 @@
 
 ;; Author: Justin Barclay <justinbarclay@gmail.com>
 ;; URL: https://github.com/justinbarclay/parinfer-rust-mode
-;; Package-Version: 0.9.3
-;; Package-Revision: v0.9.3-0-g044c3fe8f68e
-;; Package-Requires: ((emacs "26.1") (track-changes "1.1"))
+;; Package-Version: 20260101.1949
+;; Package-Revision: 6ee9f905c41f
+;; Package-Requires: ((emacs "29.2") (track-changes "1.1"))
 ;; Keywords: lisp tools
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -256,11 +256,11 @@ against and is known to be api compatible.")
   "The strategy to use when replacing the buffer's text.
 
 When set to `safe' the buffer is replaced using the slower but more
-fastiduous `replace-buffer-contents'.
+fastiduous `replace-region-contents'.
 
 When set to `fast' the buffer is replaced using `delete-region'.
 
-For more info on why the default is `replace-buffer-contents', see Info
+For more info on why the default is `replace-region-contents', see Info
 node `(elisp)Replacing'"
   :type '(radio (const :tag "Safe" safe)
                 (const :tag "Fast" fast))
@@ -424,6 +424,7 @@ See `parinfer-rust--option-type' for a more complete explanation of the options.
         'clojure-ts-mode parinfer-rust-clojure-options
         'clojure-ts-clojurescript-mode parinfer-rust-clojure-options
         'janet-mode parinfer-rust-janet-options
+        'janet-ts-mode parinfer-rust-janet-options
         'common-lisp-mode parinfer-rust-lisp-options
         'lisp-mode parinfer-rust-lisp-options
         'racket-mode parinfer-rust-racket-options
@@ -460,6 +461,9 @@ For more information see `parinfer-rust--option-type'")
 A curated list of pairs consisting of a command and the mode the
 command should be run in.")
 
+(defvar parinfer-rust--error nil
+  "The last error reported by parinfer-rust. For use with flycheck and flymake integrations.")
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Local State
 ;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -546,9 +550,11 @@ parinfer."
 
 This mutates the current reference to `OPTIONS'
 Ex:
-  (parinfer-rust--set-options parinfer-rust--previous-options ;; \='((:cursor-x . 1) (:cursor-line . 1))
-                               \='(:cursor-x 2 :cursor-line 2))
-;;=> \='((:cursor-x . 2) (:cursor-line . 2))"
+  ;; With `parinfer-rust--previous-options' being: \\='((:cursor-x . 1) (:cursor-line . 1))
+
+  (parinfer-rust--set-options parinfer-rust--previous-options
+                              \\='(:cursor-x 2 :cursor-line 2))
+;;=> \\='((:cursor-x . 2) (:cursor-line . 2))"
   (mapc (lambda (option)
           ;; Note to self set-option might need to clone in order to keep old option immutable
           (parinfer-rust-set-option options
@@ -587,11 +593,11 @@ CHANGES."
       (setq-local parinfer-rust--previous-buffer-text (buffer-substring-no-properties (point-min)
                                                                                       (point-max)))
       (let* ((parinfer-rust--mode
-              (if-let ((mode
-                        (and (string= "smart" parinfer-rust--mode)
-                             (alist-get (or this-command
-                                            last-command)
-                                        parinfer-rust-treat-command-as))))
+              (if-let* ((mode
+                         (and (string= "smart" parinfer-rust--mode)
+                              (alist-get (or this-command
+                                             last-command)
+                                         parinfer-rust-treat-command-as))))
                   (progn
                     ;; By saying a command should run under another mode, we're
                     ;; going to simplify parinfer-rust's behavior and clear all
@@ -631,9 +637,11 @@ CHANGES."
         ;; If we have an error and are not being reported by a backend, warn the user
         (if (and parinfer-error
                  (not (and (boundp 'flycheck-mode)
+                           (boundp 'flycheck--automatically-enabled-checkers)
                            (memq 'parinfer-rust flycheck--automatically-enabled-checkers)))
                  (not (and (boundp 'flymake-mode)
-                          (memq 'parinfer-rust-flymake (flymake-reporting-backends)))))
+                           (fboundp 'flymake-reporting-backends)
+                           (memq 'parinfer-rust-flymake (flymake-reporting-backends)))))
             (message "Problem on line %s: %s"
              (plist-get parinfer-error :line_no)
              (plist-get parinfer-error :message))
@@ -652,7 +660,7 @@ CHANGES."
                         (progn
                           (delete-region (point-min) (point-max))
                           (insert-buffer-substring new-buf))
-                      (setq was-replaced-safely (replace-buffer-contents new-buf 1)))
+                      (setq was-replaced-safely (replace-region-contents (point-min) (point-max) (lambda () new-buf) 1)))
                     (when (and (not was-replaced-safely)
                                (not (= window-start-pos (window-start))))
                       ;; If the buffer is not pixel aligned, this will cause a slight jump. But if
@@ -661,8 +669,8 @@ CHANGES."
                       (set-window-start (selected-window) window-start-pos)))
                   (kill-buffer new-buf)
                   (undo-amalgamate-change-group change-group)))))
-        (when-let ((new-x (parinfer-rust-get-answer answer :cursor-x))
-                   (new-line (parinfer-rust-get-answer answer :cursor-line)))
+        (when-let* ((new-x (parinfer-rust-get-answer answer :cursor-x))
+                    (new-line (parinfer-rust-get-answer answer :cursor-line)))
           (parinfer-rust--reposition-cursor new-x new-line))
         (setq parinfer-rust--previous-options options)
         (when parinfer-rust--change-tracker
@@ -712,8 +720,8 @@ parinfer autofix them, or if there is no reasonable way for
   ;; Disable change tracker for now because we are about to make changes in an change hook.
   (track-changes-unregister parinfer-rust--change-tracker)
   (setq-local parinfer-rust--change-tracker nil)
-  (if-let (issue (or (parinfer-rust--check-for-tabs)
-                     (parinfer-rust--check-for-indentation)))
+  (if-let* ((issue (or (parinfer-rust--check-for-tabs)
+                       (parinfer-rust--check-for-indentation))))
       (parinfer-rust-mode -1)
     ;; Re-enable change trackers now that we've succeeded in our tasks
     (setq-local parinfer-rust--change-tracker
